struct receiver_node {
	struct receiver *receiver;
	char *buf;
	size_t loaded;
	struct timeval chunk_tv;
	unsigned flags;
	void *private_data;
	char *host;
	int port;
};

struct receiver {
	const char *name;
	int (*init)(struct receiver *r);
	int (*open)(struct receiver_node *rn);
	void (*close)(struct receiver_node *rn);
	void (*shutdown)(void);
	int (*pre_select)(struct receiver_node *rn, fd_set *rfds, fd_set *wfds, struct timeval *timeout);
	int (*post_select)(struct receiver_node *rn, int select_ret, fd_set *rfds, fd_set *wfds);
};

enum {HEADER_WAIT = 1};

enum {	E_SELECT = 1,
	E_READ,
	E_WRITE,
	E_SYNTAX,
	E_OVERRUN,
	E_HOST_INFO,
	E_SOCKET,
	E_CONNECT,
	E_MISSING_OK,
	E_MSG_TO_BUF
};
extern int init_http_recv(struct receiver *r);
#ifdef HAVE_ORTP
extern int init_ortp_recv(struct receiver *r);
#define ORTP_RECEIVER {.name = "ortp", .init = ortp_recv_init},
#else
#define ORTP_RECEIVER
#endif

#define DEFINE_RECEIVER_ARRAY(ra) static struct receiver ra[] = { \
	{.name = "http", .init = http_recv_init}, \
	ORTP_RECEIVER \
	{.name = NULL}};
